==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSeriesDescription } from "./ScatterSeriesDescription";
/**
 * @hidden
 */
var ScatterSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesDescriptionMetadata, _super);
    function ScatterSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterSeriesDescriptionMetadata.b = function (a) {
        if (ScatterSeriesDescriptionMetadata.a == null) {
            ScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterSeriesDescriptionMetadata.c(ScatterSeriesDescriptionMetadata.a);
        }
        if (a.k(ScatterSeriesDescriptionMetadata.a)) {
            return;
        }
        a.ab(ScatterSeriesDescriptionMetadata.a);
    };
    ScatterSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
    };
    ScatterSeriesDescriptionMetadata.d = function (a) {
        ScatterSeriesDescriptionMetadata.b(a);
        a.ad("ScatterSeries", function () { return new ScatterSeriesDescription(); });
        a.ac("ScatterSeries", ScatterSeriesDescriptionMetadata.a);
    };
    ScatterSeriesDescriptionMetadata.$t = markType(ScatterSeriesDescriptionMetadata, 'ScatterSeriesDescriptionMetadata');
    ScatterSeriesDescriptionMetadata.a = null;
    return ScatterSeriesDescriptionMetadata;
}(Base));
export { ScatterSeriesDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSeriesDescription } from "./ScatterSeriesDescription";
/**
 * @hidden
 */
var ScatterSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesDescriptionMetadata, _super);
    function ScatterSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterSeriesDescriptionMetadata.b = function (a) {
        if (ScatterSeriesDescriptionMetadata.a == null) {
            ScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterSeriesDescriptionMetadata.c(ScatterSeriesDescriptionMetadata.a);
        }
        if (a.k(ScatterSeriesDescriptionMetadata.a)) {
            return;
        }
        a.ac(ScatterSeriesDescriptionMetadata.a);
    };
    ScatterSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
    };
    ScatterSeriesDescriptionMetadata.d = function (a) {
        ScatterSeriesDescriptionMetadata.b(a);
        a.ae("ScatterSeries", function () { return new ScatterSeriesDescription(); });
        a.ad("ScatterSeries", ScatterSeriesDescriptionMetadata.a);
    };
    ScatterSeriesDescriptionMetadata.$t = markType(ScatterSeriesDescriptionMetadata, 'ScatterSeriesDescriptionMetadata');
    ScatterSeriesDescriptionMetadata.a = null;
    return ScatterSeriesDescriptionMetadata;
}(Base));
export { ScatterSeriesDescriptionMetadata };
